pub fn bit_reverse_packed<P: PackedField>(buffer: FieldSliceMut<'_, P>)Expand description
Permutes the elements of a buffer by reversing the bits of every index, in place.
An index is reversed over the bit width that the length of the buffer takes. Packed representations are handled, so one exchange may move lanes within a single element.
8 elements: index 001 -> index 100Arguments
buffer- the mutable view of packed field elements to permute